==> PloneWeather-0.5.tar.gz: PloneWeather/WeatherLocation.py <==
# File: WeatherLocation.py
#
# Copyright (c) 2006 by ['Ben Hirsch']
# Generator: ArchGenXML Version 1.4.1
#            http://plone.org/products/archgenxml
#
# Berkeley Software Distribution License (BSD)
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
#   * Redistributions of source code must retain the above copyright
#     notice, this list of conditions and the following disclaimer.
#
#   * Redistributions in binary form must reproduce the above copyright
#     notice, this list of conditions and the following disclaimer in
#     the documentation and/or other materials provided with the
#     distribution.
#
#   * Neither the name of the Plone Foundation nor the names of its
#     contributors may be used to endorse or promote products derived
#     from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

__author__ = """Ben Hirsch <benh@usa.net>"""
__docformat__ = 'plaintext'

from AccessControl import ClassSecurityInfo
from Products.Archetypes.atapi import *
from Products.PloneWeather.config import *

##code-section module-header #fill in your manual code here
import time
import WeatherCurrent
from WeatherForecast import WeatherForecast
try:
    from Products.CMFCore import permissions
except ImportError:
    from Products.CMFCore import CMFCorePermissions as permissions
from Products.Archetypes import transaction
##/code-section module-header

schema = Schema((

    StringField(
        name='station',
        default="KLWM",
        widget=StringWidget(
            description="Four-letter NWS station ID",
            label='Station',
            label_msgid='PloneWeather_label_station',
            description_msgid='PloneWeather_help_station',
            i18n_domain='PloneWeather',
        ),
        required=1
    ),

    StringField(
        name='zipCode',
        default="01852",
        widget=StringWidget(
            label="ZIP Code",
            description="United States ZIP Code for obtaining forecasts",
            label_msgid='PloneWeather_label_zipCode',
            description_msgid='PloneWeather_help_zipCode',
            i18n_domain='PloneWeather',
        ),
        required=1
    ),

    IntegerField(
        name='interval',
        default=3600,
        widget=IntegerWidget(
            description="Number of seconds between updates",
            label='Interval',
            label_msgid='PloneWeather_label_interval',
            description_msgid='PloneWeather_help_interval',
            i18n_domain='PloneWeather',
        ),
        required=1
    ),

    IntegerField(
        name='daysForForecast',
        default=4,
        widget=IntegerWidget(
            label="Days for forecast",
            description="Number of days to retrieve forecast for",
            label_msgid='PloneWeather_label_daysForForecast',
            description_msgid='PloneWeather_help_daysForForecast',
            i18n_domain='PloneWeather',
        ),
        required=1
    ),

),
)

##code-section after-local-schema #fill in your manual code here
##/code-section after-local-schema

WeatherLocation_schema = BaseSchema.copy() + \
    schema.copy()

##code-section after-schema #fill in your manual code here
WeatherLocation_schema['title'].widget.visible = {'view':'hidden','edit':'hidden'}
##/code-section after-schema

class WeatherLocation(BaseContent):
    security = ClassSecurityInfo()
    __implements__ = (getattr(BaseContent,'__implements__',()),)

    # This name appears in the 'add' box
    archetype_name = 'Location'

    meta_type = 'WeatherLocation'
    portal_type = 'WeatherLocation'
    allowed_content_types = []
    filter_content_types = 0
    global_allow = 0
    allow_discussion = False
    #content_icon = 'WeatherLocation.gif'
    immediate_view = 'base_view'
    default_view = 'base_view'
    suppl_views = ()
    typeDescription = "Location"
    typeDescMsgId = 'description_edit_weatherlocation'

    actions =  (


       {'action': "string:${object_url}/configlet_weatherlocation",
        'category': "object",
        'id': 'view',
        'name': 'View',
        'permissions': ("Manage portal",),
        'condition': 'python:1'
       },


    )

    schema = WeatherLocation_schema

    ##code-section class-header #fill in your manual code here
    actions = (
        {'action':      'string:$object_url/configlet_weatherlocation',
         'category':    'object',
         'id':          'view',
         'name':        'Weather Setup',
         'permissions': (permissions.ManagePortal,),
         'visible':     False},
	
        {'action':      'string:$object_url/configlet_weatherlocation',
         'category':    'object',
         'id':          'edit',
         'name':        'Weather Setup',
         'permissions': (permissions.ManagePortal,),
         'visible':     False},
    )

    aliases = {
        '(Default)':    'configlet_weatherlocation',
        'view' :        'configlet_weatherlocation',
        'edit' :        'configlet_weatherlocation'
    }
    ##/code-section class-header

    # Methods

    # Manually created methods

    security.declarePrivate('at_post_edit_script')
    def at_post_edit_script(self):
        from LocationLookup import LocationLookup
        from string import capwords

        self.location = LocationLookup(self.getZipCode())
        self.location['City'] = capwords(self.location['City'])
        self.location['FromLongitude'] = float(self.location['FromLongitude'])
        self.location['FromLatitude'] = float(self.location['FromLatitude'])
        self.lastUpdated = 0
        self._update()

        transaction.savepoint(optimistic=True)
        self.setId(self.getZipCode())

    security.declarePublic('getLocation')
    def getLocation(self):
        """ Return the location as City, ST """
        return "%s, %s" % (self.location['City'], self.location['StateAbbrev'])

    security.declarePrivate('_update')
    def _update(self):
        # Update the weather if the diff between current time and lastUpdated
        # is greater than interval
        if self.timeSinceUpdate() > self.getInterval():
            try:
                self.currentObservation = WeatherCurrent.getCurrent(self.getStation())
                self.forecast = WeatherForecast(self.location['FromLatitude'], self.location['FromLongitude'], self.getDaysForForecast())
            except:
                return -1
            self.lastUpdated = time.time()
            return 1
        return 0

    security.declarePublic('getDaysList')
    def getDaysList(self):
        self._update()
        return self.forecast.daysList

    security.declarePublic('Title')
    def Title(self):
        """ Overridden title """
        try:
            return unicode("Weather Settings for %s" % (self.getLocation())).encode('ascii')
        except:
            return "Weather Settings"

    security.declarePublic('getCurrent')
    def getCurrent(self):
        self._update()
        return self.currentObservation

    security.declarePrivate('at_post_create_script')
    def at_post_create_script(self):
        self.at_post_edit_script()

    security.declarePublic('getForecast')
    def getForecast(self, day):
        self._update()
        return self.forecast.Forecast[day]

    security.declarePublic('timeSinceUpdate')
    def timeSinceUpdate(self):
        try:
            return time.time() - self.lastUpdated
        except:
            return self.getInterval() + 1



registerType(WeatherLocation,PROJECTNAME)
# end of class WeatherLocation

##code-section module-footer #fill in your manual code here
##/code-section module-footer

==> PloneWeather-1.0.tar.gz: PloneWeather/WeatherLocation.py <==
# File: WeatherLocation.py
#
# Copyright (c) 2006 by ['Ben Hirsch']
# Generator: ArchGenXML Version 1.4.1
#            http://plone.org/products/archgenxml
#
# Berkeley Software Distribution License (BSD)
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
#   * Redistributions of source code must retain the above copyright
#     notice, this list of conditions and the following disclaimer.
#
#   * Redistributions in binary form must reproduce the above copyright
#     notice, this list of conditions and the following disclaimer in
#     the documentation and/or other materials provided with the
#     distribution.
#
#   * Neither the name of the Plone Foundation nor the names of its
#     contributors may be used to endorse or promote products derived
#     from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

__author__ = """Ben Hirsch <benh@usa.net>"""
__docformat__ = 'plaintext'

from AccessControl import ClassSecurityInfo
from Products.Archetypes.atapi import *
from Products.PloneWeather.config import *

##code-section module-header #fill in your manual code here
import time
import WeatherCurrent
import WeatherForecast
try:
    from Products.CMFCore import permissions
except ImportError:
    from Products.CMFCore import CMFCorePermissions as permissions
from Products.Archetypes import transaction
##/code-section module-header

schema = Schema((

    StringField(
        name='station',
        default="KLWM",
        widget=StringWidget(
            description="Four-letter NWS station ID",
            label='Station',
            label_msgid='PloneWeather_label_station',
            description_msgid='PloneWeather_help_station',
            i18n_domain='PloneWeather',
        ),
        required=1
    ),

    StringField(
        name='zipCode',
        default="01852",
        widget=StringWidget(
            label="ZIP Code",
            description="United States ZIP Code for obtaining forecasts",
            label_msgid='PloneWeather_label_zipCode',
            description_msgid='PloneWeather_help_zipCode',
            i18n_domain='PloneWeather',
        ),
        required=1
    ),

    IntegerField(
        name='interval',
        default=3600,
        widget=IntegerWidget(
            description="Number of seconds between updates",
            label='Interval',
            label_msgid='PloneWeather_label_interval',
            description_msgid='PloneWeather_help_interval',
            i18n_domain='PloneWeather',
        ),
        required=1
    ),

    IntegerField(
        name='daysForForecast',
        default=4,
        widget=IntegerWidget(
            label="Days for forecast",
            description="Number of days to retrieve forecast for",
            label_msgid='PloneWeather_label_daysForForecast',
            description_msgid='PloneWeather_help_daysForForecast',
            i18n_domain='PloneWeather',
        ),
        required=1
    ),

),
)

##code-section after-local-schema #fill in your manual code here
##/code-section after-local-schema

WeatherLocation_schema = BaseSchema.copy() + \
    schema.copy()

##code-section after-schema #fill in your manual code here
WeatherLocation_schema['title'].widget.visible = {'view':'hidden','edit':'hidden'}
##/code-section after-schema

class WeatherLocation(BaseContent):
    security = ClassSecurityInfo()
    __implements__ = (getattr(BaseContent,'__implements__',()),)

    # This name appears in the 'add' box
    archetype_name = 'Location'

    meta_type = 'WeatherLocation'
    portal_type = 'WeatherLocation'
    allowed_content_types = []
    filter_content_types = 0
    global_allow = 0
    allow_discussion = False
    #content_icon = 'WeatherLocation.gif'
    immediate_view = 'base_view'
    default_view = 'base_view'
    suppl_views = ()
    typeDescription = "Location"
    typeDescMsgId = 'description_edit_weatherlocation'

    actions =  (


       {'action': "string:${object_url}/configlet_weatherlocation",
        'category': "object",
        'id': 'view',
        'name': 'View',
        'permissions': ("Manage portal",),
        'condition': 'python:1'
       },


    )

    schema = WeatherLocation_schema

    ##code-section class-header #fill in your manual code here
    actions = (
        {'action':      'string:$object_url/configlet_weatherlocation',
         'category':    'object',
         'id':          'view',
         'name':        'Weather Setup',
         'permissions': (permissions.ManagePortal,),
         'visible':     False},
	
        {'action':      'string:$object_url/configlet_weatherlocation',
         'category':    'object',
         'id':          'edit',
         'name':        'Weather Setup',
         'permissions': (permissions.ManagePortal,),
         'visible':     False},
    )

    aliases = {
        '(Default)':    'configlet_weatherlocation',
        'view' :        'configlet_weatherlocation',
        'edit' :        'configlet_weatherlocation'
    }
    ##/code-section class-header

    # Methods

    # Manually created methods

    security.declarePrivate('at_post_edit_script')
    def at_post_edit_script(self):
        from LocationLookup import LocationLookup
        from string import capwords

        self.location = LocationLookup(self.getZipCode())
        self.location['City'] = capwords(self.location['City'])
        self.location['FromLongitude'] = float(self.location['FromLongitude'])
        self.location['FromLatitude'] = float(self.location['FromLatitude'])
        self.lastUpdated = 0
        self._update()

        transaction.savepoint(optimistic=True)
        self.setId(self.getZipCode())

    security.declarePublic('getLocation')
    def getLocation(self):
        """ Return the location as City, ST """
        return "%s, %s" % (self.location['City'], self.location['StateAbbrev'])

    security.declarePrivate('_update')
    def _update(self):
        # Update the weather if the diff between current time and lastUpdated
        # is greater than interval
        if self.timeSinceUpdate() > self.getInterval():
            try:
                self.currentObservation = WeatherCurrent.getCurrent(self.getStation())
                (self.daysList, self.forecast) = WeatherForecast.getForecast(self.location['FromLatitude'], self.location['FromLongitude'], self.getDaysForForecast())
            except:
                return -1
            self.lastUpdated = time.time()
            return 1
        return 0

    security.declarePublic('getDaysList')
    def getDaysList(self):
        self._update()
        return self.daysList

    security.declarePublic('Title')
    def Title(self):
        """ Overridden title """
        try:
            return unicode("Weather Settings for %s" % (self.getLocation())).encode('ascii')
        except:
            return "Weather Settings"

    security.declarePublic('getCurrent')
    def getCurrent(self):
        self._update()
        return self.currentObservation

    security.declarePrivate('at_post_create_script')
    def at_post_create_script(self):
        self.at_post_edit_script()

    security.declarePublic('getForecast')
    def getForecast(self, day):
        self._update()
        return self.forecast[day]

    security.declarePublic('timeSinceUpdate')
    def timeSinceUpdate(self):
        try:
            return time.time() - self.lastUpdated
        except:
            return self.getInterval() + 1



registerType(WeatherLocation,PROJECTNAME)
# end of class WeatherLocation

##code-section module-footer #fill in your manual code here
##/code-section module-footer
